@@ -57,13 +57,12 @@ def job_commands():
 @click.option('-did', '--docker-image-id', help='The id of the docker image to run the job in')  # pylint: disable=all
 @click.option('-to', '--timeout', help='Timeout on the wait for a job to finish (seconds, default: 1 hour)',
               default=(60 * 60))
-@click.option('--debug-mode', hidden=True, is_flag=True)
 @click.option('--dont-generate-req-file', hidden=True, is_flag=True)
 @common_options
 @pass_state
 def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wait, instance_type, cluster_id, instance_cost,
                # pylint: disable=redefined-builtin
-               repository_id, script_file_path_in_repo, docker_image_id, timeout, debug_mode, dont_generate_req_file):
+               repository_id, script_file_path_in_repo, docker_image_id, timeout, dont_generate_req_file):
     """
     Create a new job that can be launched immediately, or later.
 
@@ -86,13 +85,13 @@ def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wa
         return
 
     if repository_id is not None and not ObjectId.is_valid(repository_id):
-        error_message('Invalid repository id (try `repository list` command)')
+        error_message('Invalid repository id (try `disco repository list` command)')
         return
     if docker_image_id is not None and not ObjectId.is_valid(docker_image_id):
-        error_message('Invalid docker image id (try `docker list` command)')
+        error_message('Invalid docker image id (try `disco docker list` command)')
         return
     if cluster_id is not None and not ObjectId.is_valid(cluster_id):
-        error_message('Invalid cluster id (try `cluster list` command)')
+        error_message('Invalid cluster id (try `disco cluster list` command)')
         return
 
     input_file_ids = []
@@ -101,7 +100,7 @@ def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wa
     if cluster_id:
         cluster = Cluster.fetch_and_validate_by_id(cluster_id)
         if not cluster:
-            error_message(f'Cluster {cluster_id} is invalid or missing (try `cluster list command`).')
+            error_message(f'Cluster {cluster_id} is invalid or missing (try `disco cluster list command`).')
             return
 
     if raw_bucket_paths:
@@ -133,11 +132,11 @@ def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wa
         messages = list(map(lambda error: error['message'], ex.errors))
         if any(msg.find('Unable to find artifacts repository') >= 0 or
                msg.find('doesn\'t own the repository provided') >= 0 for msg in messages):
-            error_message('Invalid repository id (try `repository list` command)')
+            error_message('Invalid repository id (try `disco repository list` command)')
             return
         if any(msg.find('Unable to find docker image') >= 0 or
                msg.find(f'The docker image provided (id: {docker_image_id}) doesn\'t belong') >= 0 for msg in messages):
-            error_message('Invalid docker image id (try `docker list` command)')
+            error_message('Invalid docker image id (try `disco docker list` command)')
             return
         if any(msg.find('Insufficient balance') >= 0 for msg in messages):
             info_message(' Job created')
@@ -147,15 +146,13 @@ def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wa
         for msg in messages:
             match = re.match('Cloud type \\[.*?\\] and docker image registry type', msg)
             if match is not None:
-                error_message(match.string + '\nTry `cluster list` and `docker list` commands.')
+                error_message(match.string + '\nTry `disco cluster list` and `disco docker list` commands.')
                 return
             if msg.find('Operation not supported: lowCost instance cost type on') >= 0:
                 error_message(msg)
                 return
     except DiscoException as ex:
-        if debug_mode:
-            print(ex)
-        exception_message(ex)
+        exception_message(ex, state.debug_mode)
         return
 
     job_status = None
@@ -177,13 +174,14 @@ def create_job(state, script, inputs, raw_bucket_paths, constants, name, run, wa
 
 @job_commands.command('start', context_settings=CONTEXT_SETTINGS, short_help="Start an existing job.")
 @click.argument('job_id', metavar='<JOB_ID>')
-def start_job(job_id):
+@pass_state
+def start_job(state, job_id):
     """
     Start an existing job.
 
     $ disco job start <job_id>
 
-    You may use ‘job list’ command to get the job id.
+    You may use ‘job list’ command to get the job ID.
     """
     if not verify_logged_in():
         return
@@ -198,11 +196,12 @@ def start_job(job_id):
                           'In order to continue running new jobs request more compute time.')
     except DiscoException as ex:
         error_message("Error occurred while starting job")
-        exception_message(ex)
+        exception_message(ex, state.debug_mode)
 
 
 @job_commands.command('list', context_settings=CONTEXT_SETTINGS, short_help="List all jobs and their status.")
-def list_jobs():
+@pass_state
+def list_jobs(state):
     """
     List all jobs and their status.
 
@@ -224,18 +223,19 @@ def list_jobs():
         job_list = Job.list_jobs()
         display_job_list(job_list)
     except DiscoException as ex:
-        exception_message(ex)
+        exception_message(ex, state.debug_mode)
 
 
 @job_commands.command('stop', context_settings=CONTEXT_SETTINGS, short_help="Stop a running job.")
 @click.argument('job_id', metavar='<JOB_ID>')
-def stop_job(job_id):
+@pass_state
+def stop_job(state, job_id):
     """
     Stop a running job.
 
     $ disco job stop <job_id>
 
-    You may use ‘job list’ command to get the job id.
+    You may use ‘job list’ command to get the job ID.
     """
 
     if not verify_logged_in():
@@ -245,18 +245,19 @@ def stop_job(job_id):
         job.stop()
         success_message(f"Stopping job {job_id}")
     except DiscoException as ex:
-        exception_message(ex)
+        exception_message(ex, state.debug_mode)
 
 
 @job_commands.command('archive', context_settings=CONTEXT_SETTINGS, short_help="Archive a specific job.")
 @click.argument('job_id', metavar='<JOB_ID>')
-def archive_job(job_id):
+@pass_state
+def archive_job(state,job_id):
     """
     Archive a specific job.
 
     $ disco job archive <job_id>
 
-    You may use ‘job list’ command to get the job id.
+    You may use ‘job list’ command to get the job ID.
     """
 
     if not verify_logged_in():
@@ -268,18 +269,19 @@ def archive_job(job_id):
         success_message(f"Job {job_id} was archived")
     except DiscoException as ex:
         error_message("Failed to archive job")
-        exception_message(ex)
+        exception_message(ex, state.debug_mode)
 
 
 @job_commands.command('view', context_settings=CONTEXT_SETTINGS, short_help="View specific job's details.")
 @click.argument('job_id', metavar='<JOB_ID>')
-def view_job(job_id):
+@pass_state
+def view_job(state, job_id):
     """
     View specific job's details.
 
     $ disco job view <job_id>
 
-    You may use ‘job list’ command to get the job id.
+    You may use ‘job list’ command to get the job ID.
     """
 
     if not verify_logged_in():
@@ -290,20 +292,21 @@ def view_job(job_id):
         display_job_details(details)
     except DiscoException as ex:
         error_message("Error occurred while getting job details")
-        exception_message(ex)
+        exception_message(ex, state.debug_mode)
 
 
 @job_commands.command('download-results', context_settings=CONTEXT_SETTINGS, short_help="Download results of a job.")
 @click.argument('job_id', metavar='<JOB_ID>')
 @click.option('-d', '--destination', prompt="Path for result files",
               help="The destination path to download the result files to.")
-def download_results(job_id, destination):
+@pass_state
+def download_results(state, job_id, destination):
     """
     Download results of a job.
 
     $ disco job download-results <job_id> -d <results files path>
 
-    You may use ‘job list’ command to get the job id.
+    You may use ‘job list’ command to get the job ID.
     """
 
     if not verify_logged_in():
@@ -325,17 +328,18 @@ def download_results(job_id, destination):
             success_message("Results downloaded successfully")
     except DiscoException as ex:
         error_message(f"Error occurred while getting job {job_id} results")
-        exception_message(ex)
+        exception_message(ex, state.debug_mode)
 
 @job_commands.command('tasks-list', context_settings=CONTEXT_SETTINGS, short_help="List all tasks of a job.")
 @click.argument('job_id', metavar='<JOB_ID>')
-def tasks_list(job_id):
+@pass_state
+def tasks_list(state, job_id):
     """
     List all tasks of a job.
 
     $ disco job tasks-list <job_id>
 
-    You may use ‘job list’ command to get the job id.
+    You may use ‘job list’ command to get the job ID.
 
     Status description: \n
 
@@ -354,7 +358,7 @@ def tasks_list(job_id):
         tasks_list = job.get_tasks()
         display_tasks_list(tasks_list)
     except DiscoException as ex:
-        exception_message(ex)
+        exception_message(ex, state.debug_mode)
 
 
 def display_job_list(job_list):
@@ -493,7 +497,7 @@ def _get_bucket_input_file_ids(raw_bucket_paths, cluster):
         cluster (ClusterDetails):
 
     Returns:
-        (list, bool): list of file ids and a flag if we got an error
+        (list, bool): list of file IDs and a flag if we got an error
     """
 
     is_error = True
