@@ -4,6 +4,7 @@ import moment
 from cli.command_utils import info_message, exception_message, list_to_table, verify_logged_in
 from disco import Task
 from disco.core.exceptions import DiscoException
+from .context_state import pass_state
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
@@ -16,7 +17,8 @@ def task_commands():
 @task_commands.command('show', context_settings=CONTEXT_SETTINGS,
                        short_help="Gets the activity log of the task.")
 @click.argument('task_id', metavar='<TASK_ID>')
-def show(task_id):
+@pass_state
+def show(state, task_id):
     """
     Gets the activity log of the task.
 
@@ -33,7 +35,7 @@ def show(task_id):
         else:
             info_message('No logs available yet.')
     except DiscoException as ex:
-        exception_message(ex)
+        exception_message(ex, state.debug_mode)
 
 
 def display_task_events(task_events):
