@@ -82,10 +82,10 @@ class Job(BaseController):
         """
         Uploads requirements file
         Args:
-            cluster_id: Id for cluster to upload to
+            cluster_id: ID for cluster to upload to
 
         Returns:
-            ID of rquirements file in the db
+            ID of requirements file in the DB
         """
         requirements = cls.generate_requirements()
         req_file_id = Asset().upload(
@@ -100,7 +100,7 @@ class Job(BaseController):
         """
         Generates a string of requirements for requirements file
         Returns:
-            \n seperated list of requirements
+            \n separated list of requirements
         """
         freeze_command = [sys.executable, '-m', 'pip', 'freeze']
         process = subprocess.Popen(
@@ -144,12 +144,12 @@ class Job(BaseController):
             cluster_id: Specifies the ID of the cluster on which to run the
                 job. Leave as `None` to run on DISCO's cluster.
             instace_cost: instance cost type : guaranteed or lowCost. default is None.
-            script_repo_id (str): The id of the Git repository in which the script file to run is.
+            script_repo_id (str): The ID of the Git repository in which the script file to run is.
                 (Alternative to script_file_id).
             script_file_path_in_repo (str): The path in the Git repository to the script file.
             auto_start: Automatically start the job upon creation.
             upload_requirements_file (bool): if True uploads a requirements file if in venv.
-            docker_image_id (str): The id of the docker image to run the job in.
+            docker_image_id (str): The ID of the docker image to run the job in.
 
         Returns:
             obj: The created job object.
@@ -298,7 +298,7 @@ class Job(BaseController):
         )
 
     def wait_for_status(self, *expected_statuses, interval=5, timeout=TIMEOUT):
-        """Wait for one of a job statuses.
+        """Wait for the job to be in one of the given statuses.
 
         Args:
             *expected_statuses (str): List of expected job statuses.
