@@ -60,8 +60,8 @@ class ClusterDetails(BaseModel):
     @property
     def external_account_id(self):
         """
-        External cloud account id
-        Returns (str): external account id
+        External cloud account ID
+        Returns (str): external account ID
 
         """
         return self._data.get('cluster', {}).get('externalAccountId')
