@@ -1,3 +1,4 @@
+import traceback
 from requests import ConnectionError as RequestsConnectionError, HTTPError
 import click
 from disco.core.exceptions import NoCredentials
@@ -5,15 +6,22 @@ import cli.utilities.utils as utils
 from cli.command_utils import error_message
 from cli import auth_commands, cluster_commands, job_commands, version_commands, repository_commands, \
     docker_image_commands, config_commands, task_commands
+from cli.context_state import pass_state
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
+DEBUG_MODE = False
 
 
 @click.group(context_settings=CONTEXT_SETTINGS)
-def cli():
+@click.option('-d', '--debug', default=False, is_flag=True, required=False, hidden=True, help='Run in debug mode.')
+@pass_state
+def cli(state, debug):
     """
     Root CLI Command
     """
+    state.debug_mode = debug
+    global DEBUG_MODE # pylint: disable=global-statement
+    DEBUG_MODE = state.debug_mode
 
 
 def setup_cli():
@@ -30,6 +38,7 @@ def setup_cli():
     cli.add_command(config_commands.config_commands)
     cli.add_command(task_commands.task_commands)
 
+
 def check_version():
     """
     Check if there's a newer version of the CLI
@@ -51,7 +60,7 @@ def main():
         print("Error while setting up cli")
 
     try:
-        cli()
+        cli() # pylint: disable=no-value-for-parameter
     except HTTPError:
         error_message("Unknown error received from server")
     except RequestsConnectionError:
@@ -60,7 +69,11 @@ def main():
     except NoCredentials:
         error_message("You must be logged in to perform this operation")
     except Exception:  # pylint: disable=broad-except
-        error_message("Unknown error occurred")
+        if DEBUG_MODE:
+            track = traceback.format_exc()
+            error_message(track)
+        else:
+            error_message("Unknown error occurred")
 
 
 if __name__ == '__main__':
