@@ -6,7 +6,7 @@ import shutil
 
 from disco.models import ClusterDetails
 from disco import Job
-from disco.core.exceptions import BucketPathsException, BucketPathsErrorTypes, RequestException
+from disco.core.exceptions import BucketPathsException, BucketPathsErrorTypes, RequestException, GraphQLRequestException
 from disco.core.constants import JobStatus, ClusterType
 from disco.task import TaskResult
 
@@ -156,7 +156,7 @@ class TestJobCommands(BaseTest):
         job_name = self.random_str('job_name')
         script_file_name = 'script_file.py'
 
-        invalid_cluster_error_message = f'Invalid cluster id (try `cluster list` command)'
+        invalid_cluster_error_message = f'Invalid cluster id (try `disco cluster list` command)'
 
         is_logged_in_mock.return_value = True
         cluster_fetch_and_validate_by_id.return_value = False
@@ -921,7 +921,7 @@ class TestJobCommands(BaseTest):
     @patch('disco.asset.Asset.upload')
     def test_create_job_script_file_from_git_repository(self, asset_upload_mock, path_is_dir_mock,
                                     path_exists_mock, job_create_mock, is_logged_in_mock):
-        """ Create job with script file from git repository with repository id and path. """
+        """ Create job with script file from git repository with repository ID and path. """
         job_name = self.random_str('job_name')
         input_file_id = self.random_str('input_file_id')
         repository_id = '5d5e85675533cc563218926d'
@@ -1037,7 +1037,7 @@ class TestJobCommands(BaseTest):
     @patch('disco.asset.Asset.upload')
     def test_create_job_script_file_with_docker_image(self, asset_upload_mock, path_is_dir_mock,
                                     path_exists_mock, job_create_mock, is_logged_in_mock):
-        """ Create job with script file from git repository with repository id and path. """
+        """ Create job with script file from git repository with repository ID and path. """
         job_name = self.random_str('job_name')
         input_file_id = self.random_str('input_file_id')
         repository_id = '5d67c70fe04f64038921748a'
@@ -1288,6 +1288,25 @@ class TestJobCommands(BaseTest):
         get_results_mock.assert_called()
         makedirs_mock.assert_called()
 
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    @patch('disco.Job.get_details')
+    def test_debug_mode_for_view_job_wrong_id(self, get_details_mock, is_logged_in_mock):
+        is_logged_in_mock.return_value = True
+        get_details_mock.side_effect = GraphQLRequestException(
+            message='Cannot return null for non-nullable field Query.fetchJob',
+            graphql_errors=[{'message': 'Cannot return null for non-nullable field Query.fetchJob.',
+                             'locations': [], 'path': ['fetchJob']}])
+        get_details_mock.return_value = MockViewJobResponse
+        runner = CliRunner()
+        result = runner.invoke(cli, '-d job view job_id')
+        get_details_mock.assert_called()
+        assert result.exit_code == 0
+        assert output_message_includes(result, 'Cannot return null for non-nullable field Query.fetchJob')
+        result = runner.invoke(cli, 'job view job_id')
+        get_details_mock.assert_called()
+        assert result.exit_code == 0
+        assert output_message_includes(result, 'Unknown')
+
     def test_get_files_list_of_files(self):
         runner = CliRunner()
         with runner.isolated_filesystem():
